@@ -39,9 +39,21 @@ public class vtkContextActor extends vtkProp
   public void SetScene(vtkContextScene id0)
     { SetScene_5(id0); }
 
-  private native void ReleaseGraphicsResources_6(vtkWindow id0);
+  private native void SetForceDevice_6(vtkContextDevice2D id0);
+  public void SetForceDevice(vtkContextDevice2D id0)
+    { SetForceDevice_6(id0); }
+
+  private native long GetForceDevice_7();
+  public vtkContextDevice2D GetForceDevice() {
+    long temp = GetForceDevice_7();
+
+    if (temp == 0) return null;
+    return (vtkContextDevice2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
+  private native void ReleaseGraphicsResources_8(vtkWindow id0);
   public void ReleaseGraphicsResources(vtkWindow id0)
-    { ReleaseGraphicsResources_6(id0); }
+    { ReleaseGraphicsResources_8(id0); }
 
   public vtkContextActor() { super(); }
 
