@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -149,7 +149,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetRestrictPlaneToVolume_35(int id0);
   public void SetRestrictPlaneToVolume(int id0)
@@ -225,7 +225,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void UpdatePlacement_53();
   public void UpdatePlacement()
@@ -237,7 +237,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetColorMap_55();
   public vtkImageMapToColors GetColorMap() {
@@ -245,7 +245,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkImageMapToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetColorMap_56(vtkImageMapToColors id0);
   public void SetColorMap(vtkImageMapToColors id0)
@@ -261,7 +261,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetSelectedPlaneProperty_59(vtkProperty id0);
   public void SetSelectedPlaneProperty(vtkProperty id0)
@@ -273,7 +273,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetPlaneOrientation_61(int id0);
   public void SetPlaneOrientation(int id0)
@@ -309,7 +309,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetDisplayText_69(int id0);
   public void SetDisplayText(int id0)
@@ -337,7 +337,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetMarginProperty_75(vtkProperty id0);
   public void SetMarginProperty(vtkProperty id0)
@@ -349,7 +349,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetMarginSizeX_77(double id0);
   public void SetMarginSizeX(double id0)
@@ -393,7 +393,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetTexturePlaneProperty_87(vtkProperty id0);
   public void SetTexturePlaneProperty(vtkProperty id0)
@@ -405,7 +405,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetWindowLevel_89(double id0,double id1,int id2);
   public void SetWindowLevel(double id0,double id1,int id2)
@@ -445,7 +445,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetReslice_98();
   public vtkImageReslice GetReslice() {
@@ -453,7 +453,7 @@ public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
 
     if (temp == 0) return null;
     return (vtkImageReslice)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetUseContinuousCursor_99(int id0);
   public void SetUseContinuousCursor(int id0)
